"""
This type stub file was generated by pyright.
"""

from typing import AnyStr

"""
Utilities for handling unicode and other repetitive bits
"""

def u(text: AnyStr, encoding: str = ...) -> str:
    "Return unicode text, no matter what"
    ...
